/*
   Die Kommunikation mit der Maus habe ich aus einem Forum kopiert, aber 
   das dann zu einer Klasse geschrieben und noch steps integriert, damit 
   der Roboter flüssig fährt
*/

// 

#include "Mouse.h"
#define SPEED 1500


Mouse::Mouse(int cPin, int dPin, int lStep, int rStep)
{
  clockPin = cPin;
  dataPin  = dPin;
  lStepPin = lStep;
  rStepPin = rStep;
  velX     = 0;
  velY     = 0;
}


void Mouse::gohi(int pin) {
  pinMode(pin, INPUT);
  digitalWrite(pin, HIGH);
}


void Mouse::golo(int pin) {
  pinMode(pin, OUTPUT);
  digitalWrite(pin, LOW);
}


// for doing steps
unsigned long int mouseLastStep = 0;
void Mouse::go(bool mode)
{
  if (mode && micros() - mouseLastStep >= SPEED) {
    digitalWrite(lStepPin, HIGH);
    digitalWrite(rStepPin, HIGH);
    
    mouseLastStep = micros();
    delayMicroseconds(10);
    
    digitalWrite(lStepPin, LOW);
    digitalWrite(rStepPin, LOW);
  }
}


void Mouse::write(char data, bool mode) {
  char i;
  char parity = 1;
  // put pins in output mode
  gohi(dataPin);
  gohi(clockPin);
  delayMicroseconds(300);
  golo(clockPin);
  delayMicroseconds(300);
  golo(dataPin);
  delayMicroseconds(10);
  // start bit
  gohi(clockPin);
  // wait for mouse to take control of clock);
  while (digitalRead(clockPin) == HIGH) {}
  // clock is low, and we are clear to send data
  for (i = 0; i < 8; i++) {
    if (data & 0x01) {
      gohi(dataPin);
    }
    else {
      golo(dataPin);
    }
    // wait for clock cycle
    while (digitalRead(clockPin) == LOW) {}
    go(mode);                                // may step
    while (digitalRead(clockPin) == HIGH) {}
    parity = parity ^ (data & 0x01);
    data = data >> 1;
  }
  // parity
  if (parity) {
    gohi(dataPin);
  }
  else {
    golo(dataPin);
  }
  while (digitalRead(clockPin) == LOW) {}
  go(mode);                                  // may step
  while (digitalRead(clockPin) == HIGH) {}
  // stop bit
  gohi(dataPin);
  delayMicroseconds(50);
  while (digitalRead(clockPin) == HIGH) {}
  // wait for mouse to switch modes
  while ((digitalRead(clockPin) == LOW) || (digitalRead(dataPin) == LOW)) {}
  // put a hold on the incoming data.
  golo(clockPin);
}


// Get a byte of data from the mouse
char Mouse::read(bool mode)
{
  char data = 0x00;
  int i;
  char bit = 0x01;

    // start the clock
  gohi(clockPin);
  gohi(dataPin);
  delayMicroseconds(50);
  while (digitalRead(clockPin) == HIGH) {}
  delayMicroseconds(5);   // not sure why
  while (digitalRead(clockPin) == LOW) {} // eat start bit

  for (i = 0; i < 8; i++) {
    go(mode);                                // may step
    while (digitalRead(clockPin) == HIGH) {}
    if (digitalRead(dataPin) == HIGH) {
      data = data | bit;
    }
    while (digitalRead(clockPin) == LOW) {}
    bit = bit << 1;
  }
  // eat parity bit, which we ignore
  while (digitalRead(clockPin) == HIGH) {}
  go(mode);                                  // may step
  while (digitalRead(clockPin) == LOW) {}
  // eat stop bit
  while (digitalRead(clockPin) == HIGH) {}
  go(mode);                                  // may step
  while (digitalRead(clockPin) == LOW) {}

  // put a hold on the incoming data.
  golo(clockPin);
  return data;
}


void Mouse::init()
{
  gohi(clockPin);
  gohi(dataPin);
  write(0xff, false);
  read(false);   // ack byte
  read(false);   // blank
  read(false);   // blank
  write(0xf0, false);   // remote mode
  read(false);   // ack
  delayMicroseconds(100);
}


unsigned long int Mouse::update(unsigned long int robotLastStep)
{
  static char mstat;
  static char mx;
  static char my;

  // set last step from robot
  mouseLastStep = robotLastStep;

  // get a reading from the mouse
  write(0xeb, true);  // give me data!
  read(true);         // ignore ack
  mstat = read(true);
  mx = read(true);
  my = read(true);

  // update velocity
  velX = (int) mx;
  velY = (int) my;

  // return time of last step by mouse
  return mouseLastStep;
}


bool Mouse::getX()
{
  return abs(velX) >= 16;
}


bool Mouse::getY()
{
  return abs(velY) >= 16;
}
